==> cscec5b-rmat-api-3.0.1-20230627.064423-222-sources.jar: com/ejianc/business/rmat/vo/ContInfoPriceRecordVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 周转材合同清单价格记录
 *
 * @author generator
 *
 */
public class ContInfoPriceRecordVO extends BaseEntity {
    private static final long serialVersionUID = 1L;

    //合同主键
    private String pkContract;
    //变更日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dmakedate;
    //清单主键
    private String pkLeaselist;
    //合同分录Pk
    private String pkAmountlist;
    //修订单价
    private BigDecimal nhireprice;
    //生效日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dactivedate;
    //更新时间
    private Date ts;


    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Date getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(Date dmakedate) {
        this.dmakedate = dmakedate;
    }

    public String getPkLeaselist() {
        return pkLeaselist;
    }

    public void setPkLeaselist(String pkLeaselist) {
        this.pkLeaselist = pkLeaselist;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public BigDecimal getNhireprice() {
        return nhireprice;
    }

    public void setNhireprice(BigDecimal nhireprice) {
        this.nhireprice = nhireprice;
    }

    public Date getDactivedate() {
        return dactivedate;
    }

    public void setDactivedate(Date dactivedate) {
        this.dactivedate = dactivedate;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
}

==> cscec5b-rmat-api-3.0.1-20230712.113245-230-sources.jar: com/ejianc/business/rmat/vo/ContInfoPriceRecordVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 周转材合同清单价格记录
 *
 * @author generator
 *
 */
public class ContInfoPriceRecordVO extends BaseEntity {
    private static final long serialVersionUID = 1L;

    //合同主键
    private String pkContract;
    //变更日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dmakedate;
    //清单主键
    private String pkLeaselist;
    //合同分录Pk
    private String pkAmountlist;
    //修订单价
    private BigDecimal nhireprice;
    //生效日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dactivedate;
    //更新时间
    private Date ts;
    //期初录入
    private Boolean periodFlag;

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Date getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(Date dmakedate) {
        this.dmakedate = dmakedate;
    }

    public String getPkLeaselist() {
        return pkLeaselist;
    }

    public void setPkLeaselist(String pkLeaselist) {
        this.pkLeaselist = pkLeaselist;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public BigDecimal getNhireprice() {
        return nhireprice;
    }

    public void setNhireprice(BigDecimal nhireprice) {
        this.nhireprice = nhireprice;
    }

    public Date getDactivedate() {
        return dactivedate;
    }

    public void setDactivedate(Date dactivedate) {
        this.dactivedate = dactivedate;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Boolean getPeriodFlag() {
        return periodFlag;
    }

    public void setPeriodFlag(Boolean periodFlag) {
        this.periodFlag = periodFlag;
    }
}
